@@ -197,9 +197,11 @@ class APRSDStats:
                 "enabled": p.enabled,
                 "rx": p.rx_count,
                 "tx": p.tx_count,
+                "version": p.version,
             }
 
         wl = packets.WatchList()
+        sl = packets.SeenList()
 
         stats = {
             "aprsd": {
@@ -209,7 +211,8 @@ class APRSDStats:
                 "memory_current_str": utils.human_size(self.memory),
                 "memory_peak": self.memory_peak,
                 "memory_peak_str": utils.human_size(self.memory_peak),
-                "watch_list": wl.callsigns,
+                "watch_list": wl.get_all(),
+                "seen_list": sl.get_all(),
             },
             "aprs-is": {
                 "server": self.aprsis_server,
